@@ -30,7 +30,6 @@ class AggregateBasicType(CacheableTypeBuilder, AbstractTypeBuilder):
         type_key = kwargs["type_key"]
         entity_class = registry.get_entity_class(model_class)
         aggregate_basic_type_attrs = {}
-        available_model_classes = registry.available_model_classes
 
         # Edge-case for e.g. _count, where we need to use a different type
         # than the source column. So if we count(name), we want the result
@@ -39,12 +38,8 @@ class AggregateBasicType(CacheableTypeBuilder, AbstractTypeBuilder):
         if aggregate_field_name in specialized_field_types_by_aggregate_field_name:
             registry_key = "{}{}".format(registry_key, aggregate_field_name)
 
-        for field in model_class._meta.get_fields():
-            if field.is_relation and field.related_model not in available_model_classes:
-                continue
-
-            if entity_class._field_is_excluded_or_not_included(field):
-                continue
+        for model_field in registry.get_model_fields(model_class).values():
+            field = model_field.get_django_model_field(model_class)
 
             field_name = field.name
             if field.concrete and not field.is_relation:
