@@ -1,6 +1,5 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from graphene import InputObjectType, Enum
-from djraphql.util.django_models import get_concrete_fields
 
 
 class SortDirection(Enum):
@@ -15,8 +14,10 @@ class OrderClause(CacheableTypeBuilder, AbstractTypeBuilder):
         order_by_type_attrs = {}
         model_class = kwargs["model_class"]
         entity_class = registry.get_entity_class(model_class)
-        for field in get_concrete_fields(model_class, registry.available_model_classes):
-            if entity_class._field_is_excluded_or_not_included(field):
+
+        for model_field in registry.get_model_fields(model_class).values():
+            field = model_field.get_django_model_field(model_class)
+            if not field.concrete:
                 continue
 
             # Convert names of ForeignKey/OneToOneFields from 'foo' to 'foo_id'
