@@ -9,12 +9,13 @@ class PkInputType(CacheableTypeBuilder, AbstractTypeBuilder):
     def make(registry, **kwargs):
         model_class = kwargs["model_class"]
         entity_class = registry.get_entity_class(model_class)
-        pk_fields = get_pk_fields_for_model(
-            model_class, registry.available_model_classes
-        )
+        pk_fields = registry.get_pk_fields_for_model(model_class)
+
         if len(pk_fields) == 1:
-            pk_type = pk_fields[0].get_internal_type()
-            return DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES[pk_type]
+            model_field = registry.get_model_fields(model_class)[pk_fields[0].name]
+            return model_field.get_graphene_type(
+                pk_fields[0].model, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+            )
 
         return type(
             "{}PKInputType".format(model_class.__name__),
